function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

import * as React from 'react';
var EuiIconNavInfra = function EuiIconNavInfra(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M9.572 6.036H6.43a.393.393 0 0 0-.393.393v3.142a.393.393 0 0 0 .393.393h3.142a.393.393 0 0 0 .392-.393V6.429a.393.393 0 0 0-.392-.393Zm-.393 3.142H6.823V6.822h2.356v2.356Zm5.63 0h-1.18V6.822h1.18a.393.393 0 0 0 0-.786h-1.18V3.287a.917.917 0 0 0-.915-.916h-2.75V1.193a.393.393 0 0 0-.785 0V2.37H6.823V1.193a.393.393 0 0 0-.786 0V2.37H3.288a.916.916 0 0 0-.916.916v2.75H1.194a.393.393 0 0 0 0 .785h1.178v2.356H1.194a.393.393 0 0 0 0 .786h1.178v2.749a.916.916 0 0 0 .916.916h2.75v1.178a.393.393 0 1 0 .785 0V13.63h2.356v1.178a.393.393 0 1 0 .785 0V13.63h2.75a.916.916 0 0 0 .916-.916v-2.75h1.178a.393.393 0 0 0 0-.785Zm-1.965 3.535a.13.13 0 0 1-.13.13H3.287a.13.13 0 0 1-.13-.13V3.287a.13.13 0 0 1 .13-.13h9.425a.131.131 0 0 1 .131.13v9.426Z"
  }));
};
export var icon = EuiIconNavInfra;