"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recursionDetectionMiddleware = void 0;
const recursionDetectionMiddleware = () => (next) => async (args) => next(args);
exports.recursionDetectionMiddleware = recursionDetectionMiddleware;
