"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULTS_MODE_OPTIONS = void 0;
exports.DEFAULTS_MODE_OPTIONS = ["in-region", "cross-region", "mobile", "standard", "legacy"];
