"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.areAllNiceDomain = void 0;
function areAllNiceDomain(nice) {
    return nice.length > 0 && nice.every(function (d) { return d; });
}
exports.areAllNiceDomain = areAllNiceDomain;
//# sourceMappingURL=nice.js.map