import toNumber from "./strnum.js";

describe("Should convert all the valid numeric strings to number", () => {
  it("should return undefined, null, empty string, or non-numeric as it is", () => {
      // expect(toNumber("+ 90")).toEqual("+ 90");
      // expect(toNumber("- 90")).toEqual("- 90");
      expect(toNumber("-10E2")).toEqual(100);
  });
});