"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiDescribedFormGroup", {
  enumerable: true,
  get: function get() {
    return _described_form_group.EuiDescribedFormGroup;
  }
});
var _described_form_group = require("./described_form_group");