"use strict";
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.KMS_CLIENT_USER_AGENT = exports.POTENTIAL_BRANCH_KEY_RECORD_FIELDS = exports.BEACON_KEY_TYPE_VALUE = exports.BRANCH_KEY_ACTIVE_TYPE = exports.BRANCH_KEY_TYPE_PREFIX = exports.BRANCH_KEY_ACTIVE_VERSION_FIELD = exports.BRANCH_KEY_FIELD = exports.KMS_FIELD = exports.HIERARCHY_VERSION_FIELD = exports.KEY_CREATE_TIME_FIELD = exports.TYPE_FIELD = exports.BRANCH_KEY_IDENTIFIER_FIELD = exports.CUSTOM_ENCRYPTION_CONTEXT_FIELD_PREFIX = exports.TABLE_FIELD = exports.SORT_KEY = exports.PARTITION_KEY = void 0;
exports.PARTITION_KEY = 'branch-key-id';
exports.SORT_KEY = 'type';
exports.TABLE_FIELD = 'tablename';
exports.CUSTOM_ENCRYPTION_CONTEXT_FIELD_PREFIX = 'aws-crypto-ec:';
exports.BRANCH_KEY_IDENTIFIER_FIELD = exports.PARTITION_KEY;
exports.TYPE_FIELD = exports.SORT_KEY;
exports.KEY_CREATE_TIME_FIELD = 'create-time';
exports.HIERARCHY_VERSION_FIELD = 'hierarchy-version';
exports.KMS_FIELD = 'kms-arn';
exports.BRANCH_KEY_FIELD = 'enc';
exports.BRANCH_KEY_ACTIVE_VERSION_FIELD = 'version';
exports.BRANCH_KEY_TYPE_PREFIX = 'branch:version:';
exports.BRANCH_KEY_ACTIVE_TYPE = 'branch:ACTIVE';
exports.BEACON_KEY_TYPE_VALUE = 'beacon:ACTIVE';
exports.POTENTIAL_BRANCH_KEY_RECORD_FIELDS = [
    exports.BRANCH_KEY_IDENTIFIER_FIELD,
    exports.TYPE_FIELD,
    exports.KEY_CREATE_TIME_FIELD,
    exports.HIERARCHY_VERSION_FIELD,
    exports.KMS_FIELD,
    exports.BRANCH_KEY_FIELD,
    exports.BRANCH_KEY_ACTIVE_VERSION_FIELD,
];
exports.KMS_CLIENT_USER_AGENT = 'aws-kms-hierarchy';
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiY29uc3RhbnRzLmpzIiwic291cmNlUm9vdCI6IiIsInNvdXJjZXMiOlsiLi4vLi4vLi4vc3JjL2NvbnN0YW50cy50cyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiO0FBQUEsb0VBQW9FO0FBQ3BFLHNDQUFzQzs7O0FBRXpCLFFBQUEsYUFBYSxHQUFHLGVBQWUsQ0FBQTtBQUMvQixRQUFBLFFBQVEsR0FBRyxNQUFNLENBQUE7QUFDakIsUUFBQSxXQUFXLEdBQUcsV0FBVyxDQUFBO0FBQ3pCLFFBQUEsc0NBQXNDLEdBQUcsZ0JBQWdCLENBQUE7QUFDekQsUUFBQSwyQkFBMkIsR0FBRyxxQkFBYSxDQUFBO0FBQzNDLFFBQUEsVUFBVSxHQUFHLGdCQUFRLENBQUE7QUFDckIsUUFBQSxxQkFBcUIsR0FBRyxhQUFhLENBQUE7QUFDckMsUUFBQSx1QkFBdUIsR0FBRyxtQkFBbUIsQ0FBQTtBQUM3QyxRQUFBLFNBQVMsR0FBRyxTQUFTLENBQUE7QUFDckIsUUFBQSxnQkFBZ0IsR0FBRyxLQUFLLENBQUE7QUFDeEIsUUFBQSwrQkFBK0IsR0FBRyxTQUFTLENBQUE7QUFDM0MsUUFBQSxzQkFBc0IsR0FBRyxpQkFBaUIsQ0FBQTtBQUMxQyxRQUFBLHNCQUFzQixHQUFHLGVBQWUsQ0FBQTtBQUN4QyxRQUFBLHFCQUFxQixHQUFHLGVBQWUsQ0FBQTtBQUN2QyxRQUFBLGtDQUFrQyxHQUFHO0lBQ2hELG1DQUEyQjtJQUMzQixrQkFBVTtJQUNWLDZCQUFxQjtJQUNyQiwrQkFBdUI7SUFDdkIsaUJBQVM7SUFDVCx3QkFBZ0I7SUFDaEIsdUNBQStCO0NBQ2hDLENBQUE7QUFDWSxRQUFBLHFCQUFxQixHQUFHLG1CQUFtQixDQUFBIn0=