"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFocusTrap", {
  enumerable: true,
  get: function get() {
    return _focus_trap.OuiFocusTrap;
  }
});
Object.defineProperty(exports, "EuiFocusTrap", {
  enumerable: true,
  get: function get() {
    return _focus_trap2.EuiFocusTrap;
  }
});
var _focus_trap = require("./focus_trap");
var _focus_trap2 = require("../../eui_components/focus_trap/focus_trap");