"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPickedCells = void 0;
var create_selector_1 = require("../../../../state/create_selector");
var get_last_drag_1 = require("../../../../state/selectors/get_last_drag");
var geometries_1 = require("./geometries");
exports.getPickedCells = create_selector_1.createCustomCachedSelector([geometries_1.geometries, get_last_drag_1.getLastDragSelector], function (geoms, dragState) {
    if (!dragState) {
        return null;
    }
    return geoms.pickDragArea([dragState.start.position, dragState.end.position]);
});
//# sourceMappingURL=get_picked_cells.js.map