"use strict";
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsKmsMrkAwareSymmetricKeyringNode = void 0;
const kms_keyring_1 = require("@aws-crypto/kms-keyring");
const material_management_node_1 = require("@aws-crypto/material-management-node");
exports.AwsKmsMrkAwareSymmetricKeyringNode = (0, kms_keyring_1.AwsKmsMrkAwareSymmetricKeyringClass)(material_management_node_1.KeyringNode);
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoia21zX21ya19rZXlyaW5nX25vZGUuanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMva21zX21ya19rZXlyaW5nX25vZGUudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IjtBQUFBLG9FQUFvRTtBQUNwRSxzQ0FBc0M7OztBQUV0Qyx5REFJZ0M7QUFDaEMsbUZBSTZDO0FBS2hDLFFBQUEsa0NBQWtDLEdBQzdDLElBQUEsaURBQW1DLEVBQ2pDLHNDQUFtQyxDQUNwQyxDQUFBIn0=