"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiCopy", {
  enumerable: true,
  get: function get() {
    return _copy.OuiCopy;
  }
});
Object.defineProperty(exports, "EuiCopy", {
  enumerable: true,
  get: function get() {
    return _copy2.EuiCopy;
  }
});
var _copy = require("./copy");
var _copy2 = require("../../eui_components/copy/copy");