"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiDelayHide", {
  enumerable: true,
  get: function get() {
    return _delay_hide.OuiDelayHide;
  }
});
Object.defineProperty(exports, "EuiDelayHide", {
  enumerable: true,
  get: function get() {
    return _delay_hide2.EuiDelayHide;
  }
});
var _delay_hide = require("./delay_hide");
var _delay_hide2 = require("../../eui_components/delay_hide/delay_hide");