"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotSupported = void 0;
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
class NotSupported extends Error {
    code;
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, NotSupported.prototype);
        this.code = 'NOT_SUPPORTED';
    }
}
exports.NotSupported = NotSupported;
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiZXJyb3IuanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMvZXJyb3IudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6Ijs7O0FBQUEsb0VBQW9FO0FBQ3BFLHNDQUFzQztBQUN0QyxNQUFhLFlBQWEsU0FBUSxLQUFLO0lBQ3JDLElBQUksQ0FBUTtJQUVaLFlBQVksT0FBZ0I7UUFDMUIsS0FBSyxDQUFDLE9BQU8sQ0FBQyxDQUFBO1FBQ2QsTUFBTSxDQUFDLGNBQWMsQ0FBQyxJQUFJLEVBQUUsWUFBWSxDQUFDLFNBQVMsQ0FBQyxDQUFBO1FBQ25ELElBQUksQ0FBQyxJQUFJLEdBQUcsZUFBZSxDQUFBO0lBQzdCLENBQUM7Q0FDRjtBQVJELG9DQVFDIn0=