"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFormLabel", {
  enumerable: true,
  get: function get() {
    return _form_label.OuiFormLabel;
  }
});
Object.defineProperty(exports, "EuiFormLabel", {
  enumerable: true,
  get: function get() {
    return _form_label2.EuiFormLabel;
  }
});
var _form_label = require("./form_label");
var _form_label2 = require("../../../eui_components/form/form_label/form_label");