"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiControlBar", {
  enumerable: true,
  get: function get() {
    return _control_bar.OuiControlBar;
  }
});
Object.defineProperty(exports, "EuiControlBar", {
  enumerable: true,
  get: function get() {
    return _control_bar2.EuiControlBar;
  }
});
var _control_bar = require("./control_bar");
var _control_bar2 = require("../../eui_components/control_bar/control_bar");